==> tdm_2.1.1.tar.gz: tdm/R/all.Amidihcrss.R <==
all.Amidihcrss<-function(){
     cat("\n")                                                                       
     cat("--------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous CR input data information--     \n")
     note_for_Thecrss_input()
     cat("--------------------------------------------------------------\n")  
     cat("\n")
     note_for_close_window()
     AmidihcrSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","c (mg/L)"),value=c(0))                                           
     AmidihcrSSpar<-edit(AmidihcrSSpar)                                                                                                                                          
     AmidihcrSSpar<-ycheck(AmidihcrSSpar) 
     cat("\n")                                                                                                                                        
     Amidihcr.ss(AmidihcrSSpar[8,2],AmidihcrSSpar[7,2],AmidihcrSSpar[6,2],AmidihcrSSpar[3,2],AmidihcrSSpar[2,2],AmidihcrSSpar[5,2],AmidihcrSSpar[1,2],AmidihcrSSpar[4,2]) 
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous CR input data information--    \n")
     note_for_Thecr_output()
     cat("-------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-TheCRcpr(0.8,AmidihcrSSpar[6,2],AmidihcrSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Css_pr (mg/L)")     
     show(coutput)
     cat("\n")   
     Amidihcr.more()              
}

==> tdm_2.2.2.tar.gz: tdm/R/all.Amidihcrss.R <==
all.Amidihcrss<-function(){
     cat("\n")                                                                       
     cat("--------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous CR input data information--     \n")
     note_for_Thecrss_input()
     cat("--------------------------------------------------------------\n")  
     cat("\n")
     note_for_close_window()
     AmidihcrSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","c (mg/L)"),value=c(0))                                           
     AmidihcrSSpar<-edit(AmidihcrSSpar)                                                                                                                                          
##     AmidihcrSSpar<-ycheck(AmidihcrSSpar) 
     cat("\n")                                                                                                                                        
     Amidihcr.ss(AmidihcrSSpar[8,2],AmidihcrSSpar[7,2],AmidihcrSSpar[6,2],AmidihcrSSpar[3,2],AmidihcrSSpar[2,2],AmidihcrSSpar[5,2],AmidihcrSSpar[1,2],AmidihcrSSpar[4,2]) 
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous CR input data information--    \n")
     note_for_Thecr_output()
     cat("-------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n") 
     C<-TheCRcpr(0.8,AmidihcrSSpar[6,2],AmidihcrSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Css_pr (mg/L)")     
     show(coutput)
     cat("\n")   
     Amidihcr.more()              
}
